@@ -207,13 +207,15 @@ class Database:
             "data": [],
         }
 
+        networks = []
         for netmask in range(netmask_max, netmask_min + 1):
-
             network = ipaddress.ip_network(
                 (network.split("/")[0], netmask), strict=False
             ).with_prefixlen
+            networks.append(network)
 
-            stmt = select(
+        stmt = (
+            select(
                 Device.name.label("device"),
                 Interface.name.label("interface"),
                 IP.with_prefixlen,
@@ -222,16 +224,21 @@ class Database:
                 Interface.acl_out,
                 Interface.is_disabled,
                 Interface.description,
-            ).where(
-                IP.network == network,
+            )
+            .where(
+                IP.network.in_(networks),
                 Interface.id == IP.interface_id,
                 Device.id == Interface.device_id,
             )
+            .order_by(Device.name)
+            .order_by(Interface.name)
+            .order_by(IP.with_prefixlen)
+        )
 
-            with Session(self.engine) as session:
-                for row in session.execute(stmt):
-                    data = dict(zip(result["header"], row))
-                    result["data"].append(data)
+        with Session(self.engine) as session:
+            for row in session.execute(stmt):
+                data = dict(zip(result["header"], row))
+                result["data"].append(data)
 
         return result
 
