@@ -7,11 +7,12 @@ from faddr import logger
 from faddr.database import Database
 from faddr.exceptions import (
     FaddrParserConfigFileAbsent,
+    FaddrParserConfigFileEmpty,
     FaddrParserUnknownProfile,
     FaddrSettingsFileFormatError,
 )
 from faddr.parser import Parser
-from faddr.rancid import RancidDir, RancidGroup
+from faddr.rancid import RancidDir
 from faddr.settings import load_settings
 
 
@@ -52,15 +53,16 @@ def main():
     database.new()
 
     for rancid_dir in settings.rancid.dirs:
-        if rancid_dir.kind == "dir":
-            rancid = RancidDir(rancid_dir.path)
-        elif rancid_dir.kind in ("group", "repo"):
-            rancid = RancidGroup(rancid_dir.path)
-        else:
-            continue
+        rancid = RancidDir(rancid_dir.path)
         logger.info(f"Parsing configs in rancid dir '{rancid_dir.path}'")
 
         for config in rancid.configs:
+            if not config.get("is_enabled", False):
+                logger.info(
+                    f"Config '{config['name']}' is disabled in router.db, skipping"
+                )
+                continue
+
             logger.info(f'Parsing \'{config["name"]}\' from \'{config["path"]}\'')
             try:
                 parser = Parser(
@@ -88,5 +90,7 @@ def main():
                 logger.warning(f"Unsupported config: {config}")
             except FaddrParserConfigFileAbsent:
                 logger.warning(f"Config file absent: {config}")
+            except FaddrParserConfigFileEmpty:
+                logger.warning(f"Config file empty: {config}")
 
     database.set_default()
